import { View, Text } from '@tarojs/components'
import { FC, ReactNode } from 'react'
import classnames from 'classnames'
import styles from './index.module.scss'

type TagSize = 'small' | 'normal'
type TagType = 'primary' | 'danger' | 'warning' | 'info'

interface PropsType {
  type?: TagType
  plain?: boolean
  disabled?: boolean
  size?: TagSize
  children?: ReactNode
  onClick?: Function
  circle?: boolean
  customStyle?: React.CSSProperties
}

const Tag: FC<PropsType> = (props) => {
  const { type = 'primary', size = 'normal', disabled = false, children, onClick, circle = false, customStyle = {}, plain = false } = props
  const handleClick = (event) => {
    if (disabled) {
      return
    }
    onClick && onClick(event)
  }

  const getClassName = () => {
    const classObject = {
      [styles['tag--disabled']]: disabled,
      [styles[`tag--${size}`]]: size,
      [styles[`tag--${type}`]]: type,
      [styles['tag--plain']]: plain,
      [styles['tag--circle']]: circle,
    }
    return classObject
  }
  return (
    <View className={classnames(styles.tag, getClassName())} style={customStyle} onClick={handleClick}>
      <Text className={styles['tag--text']}>{children}</Text>
    </View>
  )
}
export default Tag
