import { View, Text } from '@tarojs/components'
import { useCallback, useEffect, useMemo, useRef, useState, FC } from 'react'
import styles from './index.module.scss'
import classnames from 'classnames'
import Search from '@/components/search'
import { ClientListApi } from '@/api/order'
import Taro from '@tarojs/taro'
import { useRouter } from '@tarojs/taro'
import InfiniteScroll from '@/components/infiniteScroll'
import { dataLoadingStatus, getFilterData } from '@/common/util'
import IconText from '@/components/iconText'
import SegmentedControl from '@/components/SegmentedControl'
import IconFont from '@/components/iconfont/iconfont'
import ItemList from './components/ItemList'

// 发货列表
const Delivery: FC = () => {
  const [search, setSearch] = useState({
    name: null,
    page: 1,
    size: 10,
  })
  const [clentList, setClientlist] = useState<{ list: any[]; total: number }>({ list: [], total: 0 })

  const { fetchData: clitentFetch, state: orderState } = ClientListApi()
  //数据加载状态
  const statusMore = useMemo(() => {
    return dataLoadingStatus({ list: clentList.list, total: clentList.total, status: orderState.loading })
  }, [clentList, orderState])

  const [clientObj, setclientObj] = useState({
    clientId: null,
    clientName: '',
  })

  //输入了搜索关键字
  const getSearchData = useCallback((eq) => {
    pageNum.current.page = 1
    setClientlist(() => ({ list: [], total: 0 }))
    setSearch((e) => ({ ...e, name: eq, size: 10 }))
  }, [])

  const router = useRouter()

  useEffect(() => {
    if (search.name === '') {
      setSearch((e) => ({ ...e, name: null }))
    }
    if (search.name !== '') getCuss()
  }, [search])

  //上拉加载数据
  const pageNum = useRef({ size: search.size, page: search.page })
  const getScrolltolower = useCallback(() => {
    if (clentList.list.length < clentList.total) {
      pageNum.current.page++
      const size = pageNum.current.size * pageNum.current.page
      setSearch((e) => ({ ...e, size }))
      console.log(search, 11111)
    }
  }, [clentList])

  //列表下拉刷新
  const [refresherTriggeredStatus, setRefresherTriggeredStatus] = useState(false)
  const getRefresherRefresh = async () => {
    pageNum.current.size = 1
    setRefresherTriggeredStatus(true)
    setSearch((val) => ({ ...val, size: 10 }))
  }
  const getCuss = async () => {
    let res = await clitentFetch({ name: search.name === null ? '' : search.name, page: search.page, size: search.size })
    if (router?.params.clientId) {
      res.data.list.map((item) => {
        if (item.id == router?.params.clientId) {
          item.checked = true
        } else {
          item.checked = false
        }
        return item
      })
    }
    setClientlist((e) => ({ ...e, list: res.data?.list, total: res.data?.total }))
    setRefresherTriggeredStatus(() => false)
  }

  //选择客户
  const selectClient = (item) => {
    clentList.list.map((it) => {
      if (item.id === it.id) {
        it.checked = true
      } else {
        it.checked = false
      }
      return it
    })
    setclientObj(item)
    let pages = Taro.getCurrentPages() // 获取当前的页面栈
    let prevPage = pages[pages.length - 2]
    prevPage.setData({
      //设置上一个页面的值
      clientId: item.id,
      clientName: item.name,
    })
    setClientlist((e) => ({ ...e, list: clentList?.list, total: clentList?.total }))
    Taro.navigateBack({
      delta: 1,
    })
  }
  useEffect(() => {
    if (clientObj?.clientId !== null) {
      setclientObj(clientObj)
    } else {
      let pages = Taro.getCurrentPages() // 获取当前的页面栈
      let prevPage = pages[pages.length - 2]
      prevPage.setData({
        //设置上一个页面的值
        clientId: '',
        clientName: '',
      })
    }
  }, [clientObj])

  // 筛选列表
  const onShowFilter = () => {}

  const [statusList, setStatusList] = useState([
    {
      id: 1,
      name: '待发货',
    },
    {
      id: 2,
      name: '已完成',
    },
  ])

  // //状态改变
  const changeStatus = useCallback((e) => {
    pageNum.current.page = 1
    // setSearchField((value) => ({ ...value, status: e, size: 10 }))

    console.log(e, '123123')
    // setOrderData(() => ({ list: [], total: 0 }))
  }, [])
  // 扫描
  const handleScan = () => {}

  const scanIcon = () => {
    return (
      <View onClick={handleScan} className={styles.scanHandler}>
        <IconFont name='icon-saomiao' size={40}></IconFont>
      </View>
    )
  }

  return (
    <View className={styles.delivery}>
      <View className={styles.searchBox}>
        <Search placeholder='请输入或扫描条形码' showBtn={false} changeOnSearch={getSearchData} debounceTime={300} customRightSlot={scanIcon()}>
          <View onClick={onShowFilter} className={styles.icon__filter}>
            <IconText iconName='icon-shaixuan' text='筛选' customClass={styles['icon--filter']} />
          </View>
        </Search>
      </View>
      {/* 状态栏 */}
      <SegmentedControl list={statusList} onSelect={changeStatus} defaultId={0} />

      <View className={styles.listBox}>
        {/* <InfiniteScroll
          statusMore={statusMore}
          selfonScrollToLower={getScrolltolower}
          refresherEnabled={true}
          refresherTriggered={refresherTriggeredStatus}
          selfOnRefresherRefresh={getRefresherRefresh}>
          {clentList.list.map((item, index) => {
            return (
              <View
                className={classnames(item.checked ? styles.acticveitemBox : styles.itemBox)}
                key={index}
                onClick={() => {
                  selectClient(item)
                }}>
                <View className={styles.cussName}>{item.name}</View>
                <View className={styles.phone}>{item.phone}</View>
                <View className={styles.woker}>{item.sale_user_name}</View>
              </View>
            )
          })}
        </InfiniteScroll> */}
        <ItemList ></ItemList>
        <ItemList ></ItemList>
        <ItemList ></ItemList>
        <ItemList ></ItemList>
      </View>
    </View>
  )
}
export default Delivery
