import { View, Text, Image } from '@tarojs/components'
import MCheckbox from '@/components/checkbox'
import Counter from '@/components/counter'
import { FC, memo, ReactNode, useCallback, useEffect, useState } from 'react'
import classnames from 'classnames'
import styles from './index.module.scss'
import { debounce } from '@/common/util'
import { formatPriceDiv } from '@/common/format'
import { EnumSaleMode } from '@/common/Enumerate'
import { useNeedMemoCallback } from '@/use/useCommon'
import {selectList} from '../../config'
type PropsType = {
  item: Record<string, any> & object
  orderType: EnumSaleMode
  isSelected: boolean
  onChecked?: Function
  onUnChecked?: Function
}

const ColorKindItem: FC<PropsType> = memo(
  (props) => {
    const { item, orderType = EnumSaleMode.Bulk, isSelected = false, onChecked, onUnChecked } = props
    console.log('重新渲染', item.id, orderType)
    //格式化金额
    const formatPirce = useCallback((price) => {
      return Number(formatPriceDiv(price))
    }, [])

    //格式化数量
    const formatCount = useCallback((item) => {
      return item.sale_mode == EnumSaleMode.Bulk ? item.roll : item.length / 100
    }, [])

    //格式化单位
    const formatUnit = useCallback((item) => {
      return item.sale_mode == EnumSaleMode.Bulk ? '条' : '米'
    }, [])

    const handleSelect = () => {
      console.log('handleSelect')
      // setCheck(true)
      onChecked && onChecked({ ...item, checked: true })
    }
    const handleClose = () => {
      // setCheck(false)
      onUnChecked && onUnChecked({ ...item, checked: false })
    }

    const getInputValue = debounce(async (num, item) => {
      if (item.sale_mode === EnumSaleMode.Bulk) {
        item.roll = num
      }else{
        item.length = num
      } 
      onChecked && onChecked({ ...item, checked: true })
    }, 300)

    return (
      <MCheckbox
        triggerLabel={false}
        status={isSelected}
        onSelect={handleSelect}
        onClose={handleClose}
        customClassName={classnames(styles.checkbox, isSelected ? styles.selected : '')}
        customTextClass={styles.colorKindItem}>
        <View className={styles['colorKindItem__left']}>
          <Image className={styles['colorKindItem__left--image']} mode='aspectFill' src='https://test.cdn.zzfzyc.com/mall/no_img.png'></Image>
        </View>
        <View className={styles['colorKindItem__center']}>
          <Text className={styles['colorKindItem__center--title']}>001# 环保黑 环保黑 环保黑 环保黑 环保黑 环保黑</Text>
          <View className={styles['colorKindItem__center--detail']}>
            <Text className={styles['colorKindItem__center--ID']}>6002#220G</Text>
            <Text className={styles['colorKindItem__center--description']}>流线棉拉架卫衣</Text>
          </View>
        </View>
        <View className={styles['colorKindItem__right']}>
          <View className={styles['colorKindItem__right--price']}>￥ 37.50/kg</View>
          <View className={styles['colorKindItem__right--counter']}>
            <Counter
              onBlue={(e) => getInputValue(e, item)}
              defaultNum={formatCount(item)}
              step={selectList[orderType].step}
              digits={selectList[orderType].digits}
              onClickBtn={(e) => getInputValue(e, item)}
              unit={formatUnit(item)}
              minNum={selectList[orderType].minNum}
              maxNum={selectList[orderType].maxNum}
            />
          </View>
        </View>
      </MCheckbox>
    )
  },
  (preProp, nextProp) => {
    const stringifyPreProp = JSON.stringify(preProp.item)
    const stringifyNextProp = JSON.stringify(nextProp.item)
    console.log('memo==>', preProp, nextProp);
    let needMemoized = true
    if (preProp.isSelected !== nextProp.isSelected) {
      needMemoized = false
    }
    if (preProp.orderType !== nextProp.orderType) {
      needMemoized = false
    }
    if (stringifyPreProp !== stringifyNextProp) {
      needMemoized = false
    }
    return needMemoized
  },
)
export default ColorKindItem
